@@ -3,9 +3,9 @@ Main interface for sso-oidc service type definitions.
 
 Usage::
 
-    from mypy_boto3.sso_oidc.type_defs import ClientCreateTokenResponseTypeDef
+    from mypy_boto3.sso_oidc.type_defs import CreateTokenResponseTypeDef
 
-    data: ClientCreateTokenResponseTypeDef = {...}
+    data: CreateTokenResponseTypeDef = {...}
 """
 import sys
 
@@ -16,19 +16,19 @@ else:
 
 
 __all__ = (
-    "ClientCreateTokenResponseTypeDef",
-    "ClientRegisterClientResponseTypeDef",
-    "ClientStartDeviceAuthorizationResponseTypeDef",
+    "CreateTokenResponseTypeDef",
+    "RegisterClientResponseTypeDef",
+    "StartDeviceAuthorizationResponseTypeDef",
 )
 
-ClientCreateTokenResponseTypeDef = TypedDict(
-    "ClientCreateTokenResponseTypeDef",
+CreateTokenResponseTypeDef = TypedDict(
+    "CreateTokenResponseTypeDef",
     {"accessToken": str, "tokenType": str, "expiresIn": int, "refreshToken": str, "idToken": str},
     total=False,
 )
 
-ClientRegisterClientResponseTypeDef = TypedDict(
-    "ClientRegisterClientResponseTypeDef",
+RegisterClientResponseTypeDef = TypedDict(
+    "RegisterClientResponseTypeDef",
     {
         "clientId": str,
         "clientSecret": str,
@@ -40,8 +40,8 @@ ClientRegisterClientResponseTypeDef = TypedDict(
     total=False,
 )
 
-ClientStartDeviceAuthorizationResponseTypeDef = TypedDict(
-    "ClientStartDeviceAuthorizationResponseTypeDef",
+StartDeviceAuthorizationResponseTypeDef = TypedDict(
+    "StartDeviceAuthorizationResponseTypeDef",
     {
         "deviceCode": str,
         "userCode": str,
